@@ -9,6 +9,10 @@ from datetime import datetime
 import requests
 import calendar
 
+import pandas as pd
+
+from datetime import  timedelta
+
 class NaPoleonBinanceFutureBot(object):
 
     def __init__(self, BINANCE_PUBLIC, BINANCE_PRIVATE):
@@ -46,6 +50,104 @@ class NaPoleonBinanceFutureBot(object):
         self.cancel_all_order('TRX/USDT')
 
 
+    def get_balance_snapshot(self, request_date):
+
+        start_time = request_date
+        end_time = request_date + timedelta(days = 1)
+
+        startTime = int(start_time.timestamp() * 1000)
+        endTime = int(end_time.timestamp() * 1000)
+
+        BASE_URL = 'https://api.binance.com'
+        PATH = '/sapi/v1/accountSnapshot'
+
+        headers = {
+            'X-MBX-APIKEY': self.apiKey
+        }
+        timestamp = int(time.time() * 1000)
+
+        params = {
+            'type': 'FUTURES',
+            'recvWindow': 60000,
+            'timestamp': timestamp,
+            'startTime': startTime,
+            'endTime': endTime,
+            'limit':30
+
+        }
+        query_string = urllib.parse.urlencode(params)
+        params['signature'] = hmac.new(self.secret.encode('utf-8'), query_string.encode('utf-8'),
+                                       hashlib.sha256).hexdigest()
+        url = urljoin(BASE_URL, PATH)
+        print(url)
+        r = requests.get(url, headers=headers, params=params)
+        dataSet = r.json()
+
+        snapshots = dataSet['snapshotVos']
+
+        concatenated_df = None
+        for me_snapshot in snapshots:
+            data_df = pd.DataFrame(me_snapshot['data']['assets'])
+            data_df['updateTime'] = me_snapshot['updateTime']
+            if concatenated_df is None:
+                concatenated_df = data_df.copy()
+            else :
+                concatenated_df = pd.concat([concatenated_df, data_df])
+
+        concatenated_df['date'] = pd.to_datetime(concatenated_df['updateTime'], unit='ms')
+        concatenated_df['date'] = concatenated_df['date'] + timedelta(seconds=1)
+
+        concatenated_df = concatenated_df[concatenated_df['date'] == request_date]
+
+        return concatenated_df
+
+
+    def get_balance_history(self, start_time, end_time):
+
+        startTime = int(start_time.timestamp() * 1000)
+        endTime = int(end_time.timestamp() * 1000)
+
+        BASE_URL = 'https://api.binance.com'
+        PATH = '/sapi/v1/accountSnapshot'
+
+        headers = {
+            'X-MBX-APIKEY': self.apiKey
+        }
+        timestamp = int(time.time() * 1000)
+
+        params = {
+            'type': 'FUTURES',
+            'recvWindow': 60000,
+            'timestamp': timestamp,
+            'startTime': startTime,
+            'endTime': endTime,
+            'limit':30
+
+        }
+        query_string = urllib.parse.urlencode(params)
+        params['signature'] = hmac.new(self.secret.encode('utf-8'), query_string.encode('utf-8'),
+                                       hashlib.sha256).hexdigest()
+        url = urljoin(BASE_URL, PATH)
+        print(url)
+        r = requests.get(url, headers=headers, params=params)
+        dataSet = r.json()
+
+        snapshots = dataSet['snapshotVos']
+
+        concatenated_df = None
+        for me_snapshot in snapshots:
+            data_df = pd.DataFrame(me_snapshot['data']['assets'])
+            data_df['updateTime'] = me_snapshot['updateTime']
+            if concatenated_df is None:
+                concatenated_df = data_df.copy()
+            else :
+                concatenated_df = pd.concat([concatenated_df, data_df])
+
+        concatenated_df['date'] = pd.to_datetime(concatenated_df['updateTime'], unit='ms')
+        concatenated_df['date'] = concatenated_df['date'] + timedelta(seconds=1)
+
+        return concatenated_df
+
     def get_balance_low_level(self, request_date):
         BASE_URL = 'https://api.binance.com'
         PATH = '/api/v3/account'
