@@ -408,30 +408,15 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     ohlc_eth_cc_pkl_file_name = f'{filename_stub}_ohlc_eth_cc.pkl'
     balance_pkl_file_name = f'{filename_stub}_balance.pkl'
 
-
     initial_balances = binance_get_histo_balance(public_key, private_key, start_time)
 
-    ohlc_bnb_min_binance = binance_get(public_key, private_key, 'spot_klines', start_time, end_time=end_time, symbol ='BNBUSDT', aggreg ='1m')
-
-    initial_bnb_balance = 0
-    initial_usdt_balance = 0
-    try:
-        initial_bnb_balance = initial_balances[initial_balances['asset'] == 'BNB']['walletBalance'][0]
-    except Exception as e:
-        print(e)
-    try:
-        initial_usdt_balance = initial_balances[initial_balances['asset'] == 'USDT']['walletBalance'][0]
-    except Exception as e:
-        print(e)
-
-    initial_usd_balance = initial_usdt_balance + initial_bnb_balance * ohlc_bnb_min_binance.iloc[start_time]
-    print(initial_usd_balance)
-
     trades = binance_get(public_key, private_key, 'trade_history', start_time, end_time=end_time, symbol ='ETHUSDT').drop_duplicates()
     ohlc_eth_binance = binance_get(public_key, private_key, 'futures_klines', start_time, end_time= end_time, symbol ='ETHUSDT', aggreg ='1m')
     ohlc_btc_binance = binance_get(public_key, private_key, 'futures_klines', start_time, end_time= end_time, symbol ='BTCUSDT', aggreg ='1m')
     walletHist = binance_get(public_key, private_key, 'wallet_history', start_time, end_time= end_time, symbol ='ETHUSDT')
 
+    ohlc_bnb_min_binance = binance_get(public_key, private_key, 'spot_klines', start_time, end_time=end_time, symbol ='BNBUSDT', aggreg ='1m')
+
 
     # Get datacryptocompare
     cc = CryptoCompare('afb994efa0ca3fc08f6b4b4b1ce74d3cfdfbf962b4c2e6fe4a5694dd37cd68aa')
@@ -598,9 +583,23 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     wh['dt_floor_h'] = wh.index.map(lambda x: x.floor('H'))
     wh = wh.groupby('dt_floor_h').sum()
     wh['pnl'] = wh['realized_pnl']
-    initial_pnl = wh.at[wh.index[0], 'realized_pnl']
-    starting_value = 10000
-    wh.at[wh.index[0], 'realized_pnl'] = initial_pnl + starting_value  # qqlq k en mars
+
+    initial_bnb_balance = 0
+    initial_usdt_balance = 0
+    try:
+        initial_bnb_balance = float(initial_balances[initial_balances['asset'] == 'BNB']['walletBalance'].iloc[0])
+    except Exception as e:
+        print(e)
+    try:
+        initial_usdt_balance = float(initial_balances[initial_balances['asset'] == 'USDT']['walletBalance'].iloc[0])
+    except Exception as e:
+        print(e)
+
+    bnb_rate = ohlc_bnb_min_binance.loc[start_time]['open_bnb_bnc']
+    initial_usd_balance = initial_usdt_balance + initial_bnb_balance * bnb_rate
+    print(f'initial usdt balance {initial_usd_balance}')
+
+    wh.at[wh.index[0], 'realized_pnl'] = initial_usd_balance
 
     wh['net_profit'] = wh.realized_pnl + wh.funding_fees_eth_usd + wh.funding_fees_xbt_usd + wh.trading_fees_eth_usd + wh.trading_fees_xbt_usd
     wh['valuation'] = wh.net_profit + wh.transfers_usd
